@@ -8,7 +8,7 @@ import subprocess
 def cffi_version():
     with open('lib_pypy/cffi/__init__.py', encoding='UTF-8') as f:
         for line in f:
-            m = re.match(r'^__version__ = "([0-9.]+)"$', line)
+            m = re.match(r'^__version__ = "([0-9.]+)(?:\.dev\d+)?"$', line)
             if m:
                 return m.group(1)
     raise Exception('Version not found')
@@ -41,7 +41,7 @@ def pypy_abi():
     if 'pypy3' not in subprocess.check_output(('dh_listpackages',)).split():
         return ''
     soabi = subprocess.check_output((
-        'pypy/goal/pypy3-c', '-c',
+        'pypy/goal/pypy3.9-c', '-c',
         'import sysconfig; print(sysconfig.get_config_var("SOABI"))'))
     return soabi.strip().replace('-', '-abi-')
 
